@@ -25,197 +25,138 @@ IWL::Stock->new
 my $Stock = {
     IWL_STOCK_ADD => {
 	smallImage => $IWLConfig{ICON_DIR} . "/add." . $IWLConfig{ICON_EXT},
-        label       => N__ "Add",
+	label      => N__ "Add",
     },
     IWL_STOCK_APPLY => {
 	smallImage => $IWLConfig{ICON_DIR} . "/apply." . $IWLConfig{ICON_EXT},
-        label       => N__ "Apply",
+	label      => N__ "Apply",
     },
-    IWL_STOCK_BACK => {
-        smallImage => $IWLConfig{ICON_DIR} . "/back." . $IWLConfig{ICON_EXT},
-        label       => N__ "Back",
+    IWL_STOCK_CALENDAR => {
+        smallImage => $IWLConfig{ICON_DIR} . "/calendar." . $IWLConfig{ICON_EXT},
+        label      => N__ "Calendar",
     },
     IWL_STOCK_CANCEL => {
         smallImage => $IWLConfig{ICON_DIR} . "/cancel." . $IWLConfig{ICON_EXT},
-        label       => N__ "Cancel",
+        label      => N__ "Cancel",
     },
     IWL_STOCK_CLEAR => {
         smallImage => $IWLConfig{ICON_DIR} . "/clear." . $IWLConfig{ICON_EXT},
-        label       => N__ "Clear",
+        label      => N__ "Clear",
     },
     IWL_STOCK_CLOSE => {
         smallImage => $IWLConfig{ICON_DIR} . "/close." . $IWLConfig{ICON_EXT},
-        label       => N__ "Close",
+        label      => N__ "Close",
     },
     IWL_STOCK_DELETE => {
         smallImage => $IWLConfig{ICON_DIR} . "/delete." . $IWLConfig{ICON_EXT},
-        label       => N__ "Delete",
-    },
-    IWL_STOCK_DOWNLOAD => {
-        smallImage => $IWLConfig{ICON_DIR} . "/download." . $IWLConfig{ICON_EXT},
-        label       => N__ "Download",
-    },
-    IWL_STOCK_EDIT => {
-        smallImage => $IWLConfig{ICON_DIR} . "/edit." . $IWLConfig{ICON_EXT},
-        label       => N__ "Edit",
-    },
-    IWL_STOCK_EXPORT => {
-        smallImage => $IWLConfig{ICON_DIR} . "/export." . $IWLConfig{ICON_EXT},
-        label       => N__ "Export",
-    },
-    IWL_STOCK_FULLSCREEN => {
-        smallImage => $IWLConfig{ICON_DIR} . "/fullscreen." . $IWLConfig{ICON_EXT},
-        label       => N__ "Fullscreen",
-    },
-    IWL_STOCK_GO => {
-        smallImage => $IWLConfig{ICON_DIR} . "/go." . $IWLConfig{ICON_EXT},
-        label       => N__ "Go",
-    },
-    IWL_STOCK_GO_BACK => {
-        smallImage => $IWLConfig{ICON_DIR} . "/go_back." . $IWLConfig{ICON_EXT},
-        label       => N__ "Go back",
-    },
-    IWL_STOCK_GO_FORWARD => {
-        smallImage => $IWLConfig{ICON_DIR} . "/go_forward." . $IWLConfig{ICON_EXT},
-        label       => N__ "Go forward",
-    },
-    IWL_STOCK_GOTO_FIRST => {
-        smallImage => $IWLConfig{ICON_DIR} . "/first." . $IWLConfig{ICON_EXT},
-        label       => N__ "Go to first",
-    },
-    IWL_STOCK_GOTO_LAST => {
-        smallImage => $IWLConfig{ICON_DIR} . "/last." . $IWLConfig{ICON_EXT},
-        label       => N__ "Go to last",
-    },
-    IWL_STOCK_HELP => {
-        smallImage => $IWLConfig{ICON_DIR} . "/help." . $IWLConfig{ICON_EXT},
-        label       => N__ "Help",
-    },
-    IWL_STOCK_INFO => {
-        smallImage => $IWLConfig{ICON_DIR} . "/info." . $IWLConfig{ICON_EXT},
-        label       => N__ "Information",
-    },
-    IWL_STOCK_LOCK => {
-        smallImage => $IWLConfig{ICON_DIR} . "/lock." . $IWLConfig{ICON_EXT},
-        label       => N__ "Lock",
-    },
-    IWL_STOCK_MINIMIZE => {
-        smallImage => $IWLConfig{ICON_DIR} . "/minimize." . $IWLConfig{ICON_EXT},
-        label       => N__ "Minimize",
-    },
-    IWL_STOCK_NEW => {
-        smallImage => $IWLConfig{ICON_DIR} . "/new." . $IWLConfig{ICON_EXT},
-        label       => N__ "New",
-    },
-    IWL_STOCK_NEXT => {
-        smallImage => $IWLConfig{ICON_DIR} . "/next." . $IWLConfig{ICON_EXT},
-        label       => N__ "Next",
-    },
-    IWL_STOCK_OK => {
-        smallImage => $IWLConfig{ICON_DIR} . "/ok." . $IWLConfig{ICON_EXT},
-        label       => N__ "OK",
-    },
-    IWL_STOCK_PREFERENCES => {
-        smallImage => $IWLConfig{ICON_DIR} . "/preferences." . $IWLConfig{ICON_EXT},
-        label       => N__ "Preferences",
-    },
-    IWL_STOCK_PREVIEW => {
-        smallImage => $IWLConfig{ICON_DIR} . "/preview." . $IWLConfig{ICON_EXT},
-        label       => N__ "Preview",
-    },
-    IWL_STOCK_REFRESH => {
-        smallImage => $IWLConfig{ICON_DIR} . "/refresh." . $IWLConfig{ICON_EXT},
-        label       => N__ "Refresh",
-    },
-    IWL_STOCK_REMOVE => {
-        smallImage => $IWLConfig{ICON_DIR} . "/remove." . $IWLConfig{ICON_EXT},
-        label       => N__ "Remove",
-    },
-    IWL_STOCK_SAVE => {
-        smallImage => $IWLConfig{ICON_DIR} . "/save." . $IWLConfig{ICON_EXT},
-        label       => N__ "Save",
-    },
-    IWL_STOCK_SAVE_CLOSE => {
-        smallImage => $IWLConfig{ICON_DIR} . "/save_close." . $IWLConfig{ICON_EXT},
-        label       => N__ "Save and close",
-    },
-    IWL_STOCK_UPLOAD => {
-        smallImage => $IWLConfig{ICON_DIR} . "/upload." . $IWLConfig{ICON_EXT},
-        label       => N__ "Upload",
-    },
-
-    IWL_STOCK_DESKTOP_ADD_FILTER => {
-        smallImage => $IWLConfig{ICON_DIR} . "/desktop_add_filter." . $IWLConfig{ICON_EXT},
-        label       => N__ "Add Filter",
+        label      => N__ "Delete",
     },
     IWL_STOCK_DIRECTORY => {
         smallImage => $IWLConfig{ICON_DIR} . "/directory." . $IWLConfig{ICON_EXT},
-        label       => N__ "Directory",
-    },
-    IWL_STOCK_DIRECTORY_DELETE => {
-        smallImage => $IWLConfig{ICON_DIR} . "/directory_delete." . $IWLConfig{ICON_EXT},
-        label       => N__ "Delete directory",
-    },
-    IWL_STOCK_DIRECTORY_EDIT => {
-        smallImage => $IWLConfig{ICON_DIR} . "/directory_edit." . $IWLConfig{ICON_EXT},
-        label       => N__ "Edit directory",
+        label      => N__ "Directory",
     },
     IWL_STOCK_DIRECTORY_NEW => {
         smallImage => $IWLConfig{ICON_DIR} . "/directory_new." . $IWLConfig{ICON_EXT},
-        label       => N__ "Create directory",
+        label      => N__ "Create directory",
     },
-
-    IWL_STOCK_TOOLBAR_BOTTOM => {
-        smallImage => $IWLConfig{ICON_DIR} . "/toolbar-bottom." . $IWLConfig{ICON_EXT},
-        label       => N__ "Bottom",
+    IWL_STOCK_DOWNLOAD => {
+        smallImage => $IWLConfig{ICON_DIR} . "/download." . $IWLConfig{ICON_EXT},
+        label      => N__ "Download",
     },
-    IWL_STOCK_TOOLBAR_HOME => {
-        smallImage => $IWLConfig{ICON_DIR} . "/toolbar-home." . $IWLConfig{ICON_EXT},
-        label       => N__ "Main menu",
+    IWL_STOCK_EDIT => {
+        smallImage => $IWLConfig{ICON_DIR} . "/edit." . $IWLConfig{ICON_EXT},
+        label      => N__ "Edit",
     },
-    IWL_STOCK_TOOLBAR_INFO => {
-        smallImage => $IWLConfig{ICON_DIR} . "/toolbar-info." . $IWLConfig{ICON_EXT},
-        label       => N__ "Info",
+    IWL_STOCK_FULLSCREEN => {
+        smallImage => $IWLConfig{ICON_DIR} . "/fullscreen." . $IWLConfig{ICON_EXT},
+        label      => N__ "Fullscreen",
     },
-    IWL_STOCK_TOOLBAR_MAIL => {
-        smallImage => $IWLConfig{ICON_DIR} . "/toolbar-mail." . $IWLConfig{ICON_EXT},
-        label       => N__ "Mail",
+    IWL_STOCK_GO_BACK => {
+        smallImage => $IWLConfig{ICON_DIR} . "/go_back." . $IWLConfig{ICON_EXT},
+        label      => N__ "Go back",
     },
-    IWL_STOCK_TOOLBAR_MENU => {
-        smallImage => $IWLConfig{ICON_DIR} . "/toolbar-menu." . $IWLConfig{ICON_EXT},
-        label       => N__ "Main menu",
+    IWL_STOCK_GO_DOWN => {
+        smallImage => $IWLConfig{ICON_DIR} . "/go_down." . $IWLConfig{ICON_EXT},
+        label      => N__ "Go down",
     },
-    IWL_STOCK_TOOLBAR_QUIT => {
-        smallImage => $IWLConfig{ICON_DIR} . "/toolbar-quit." . $IWLConfig{ICON_EXT},
-        label       => N__ "Quit",
+    IWL_STOCK_GO_FORWARD => {
+        smallImage => $IWLConfig{ICON_DIR} . "/go_forward." . $IWLConfig{ICON_EXT},
+        label      => N__ "Go forward",
     },
-    IWL_STOCK_TOOLBAR_ROLES => {
-        smallImage => $IWLConfig{ICON_DIR} . "/toolbar-roles." . $IWLConfig{ICON_EXT},
-        label       => N__ "Available roles",
+    IWL_STOCK_GO_UP => {
+        smallImage => $IWLConfig{ICON_DIR} . "/go_up." . $IWLConfig{ICON_EXT},
+        label      => N__ "Go up",
     },
-    IWL_STOCK_TOOLBAR_TOP => {
-        smallImage => $IWLConfig{ICON_DIR} . "/toolbar-top." . $IWLConfig{ICON_EXT},
-        label       => N__ "Top",
+    IWL_STOCK_GOTO_FIRST => {
+        smallImage => $IWLConfig{ICON_DIR} . "/first." . $IWLConfig{ICON_EXT},
+        label      => N__ "Go to first",
     },
-
-    IWL_STOCK_CALENDAR => {
-        smallImage => $IWLConfig{ICON_DIR} . "/calendar." . $IWLConfig{ICON_EXT},
-        label       => N__ "Calendar",
+    IWL_STOCK_GOTO_LAST => {
+        smallImage => $IWLConfig{ICON_DIR} . "/last." . $IWLConfig{ICON_EXT},
+        label      => N__ "Go to last",
+    },
+    IWL_STOCK_HELP => {
+        smallImage => $IWLConfig{ICON_DIR} . "/help." . $IWLConfig{ICON_EXT},
+        label      => N__ "Help",
+    },
+    IWL_STOCK_INFO => {
+        smallImage => $IWLConfig{ICON_DIR} . "/info." . $IWLConfig{ICON_EXT},
+        label      => N__ "Information",
+    },
+    IWL_STOCK_LOCK => {
+        smallImage => $IWLConfig{ICON_DIR} . "/lock." . $IWLConfig{ICON_EXT},
+        label      => N__ "Lock",
+    },
+    IWL_STOCK_NEW => {
+        smallImage => $IWLConfig{ICON_DIR} . "/new." . $IWLConfig{ICON_EXT},
+        label      => N__ "New",
+    },
+    IWL_STOCK_NEXT => {
+        smallImage => $IWLConfig{ICON_DIR} . "/next." . $IWLConfig{ICON_EXT},
+        label      => N__ "Next",
+    },
+    IWL_STOCK_OK => {
+        smallImage => $IWLConfig{ICON_DIR} . "/ok." . $IWLConfig{ICON_EXT},
+        label      => N__ "OK",
+    },
+    IWL_STOCK_PREFERENCES => {
+        smallImage => $IWLConfig{ICON_DIR} . "/preferences." . $IWLConfig{ICON_EXT},
+        label      => N__ "Preferences",
+    },
+    IWL_STOCK_PREVIEW => {
+        smallImage => $IWLConfig{ICON_DIR} . "/preview." . $IWLConfig{ICON_EXT},
+        label      => N__ "Preview",
+    },
+    IWL_STOCK_PREVIOUS => {
+        smallImage => $IWLConfig{ICON_DIR} . "/previous." . $IWLConfig{ICON_EXT},
+        label      => N__ "Previous",
+    },
+    IWL_STOCK_REFRESH => {
+        smallImage => $IWLConfig{ICON_DIR} . "/refresh." . $IWLConfig{ICON_EXT},
+        label      => N__ "Refresh",
+    },
+    IWL_STOCK_REMOVE => {
+        smallImage => $IWLConfig{ICON_DIR} . "/remove." . $IWLConfig{ICON_EXT},
+        label      => N__ "Remove",
+    },
+    IWL_STOCK_SAVE => {
+        smallImage => $IWLConfig{ICON_DIR} . "/save." . $IWLConfig{ICON_EXT},
+        label      => N__ "Save",
+    },
+    IWL_STOCK_UPLOAD => {
+        smallImage => $IWLConfig{ICON_DIR} . "/upload." . $IWLConfig{ICON_EXT},
+        label      => N__ "Upload",
     },
 
     IWL_STOCK_TEXT_X_GENERIC => {
         smallImage => $IWLConfig{ICON_DIR} . "/text_x_generic." . $IWLConfig{ICON_EXT},
-        label       => N__ "Generic Text",
-    },
-    IWL_STOCK_TEXT_X_ARCHIVE => {
-        smallImage => $IWLConfig{ICON_DIR} . "/text_x_archive." . $IWLConfig{ICON_EXT},
-        label       => N__ "Generic Text",
+        label      => N__ "Generic Text",
     },
 };
 
 sub new {
     my $class = shift;
-    my $self  = bless {}, $class;
+    my $self  = bless {stock => $Stock}, $class;
 
     return $self;
 }
@@ -266,6 +207,33 @@ sub exists {
     return exists $Stock->{$stock_id};
 }
 
+=item B<add> (B<STOCK_KEY> => B<STOCK_ITEM>, ...)
+
+Adds the given stock items to the list of existing items
+
+Parameters: B<STOCK_KEY> - the stock key of the item, B<STOCK_ITEM> - A stock item to add to the stock repository. It is a hash reference with the following keys:
+
+=over 8
+
+=item B<smallImage>
+
+The URL of the small image, usually with a size of 16x16
+
+=item B<label>
+
+The label for this stock item
+
+=back
+
+=cut
+
+sub add {
+    my ($self, %stock_items) = @_;
+
+    $Stock->{$_} = $stock_items{$_} foreach keys %stock_items;
+    return $self;
+}
+
 1;
 
 =head1 LICENCE AND COPYRIGHT
