@@ -15,7 +15,7 @@ IWL::Textarea - a text area widget
 
 =head1 INHERITANCE
 
-L<IWL::Object> -> L<IWL::Widget> -> L<IWL::Input> -> L<IWL::Textarea>
+L<IWL::Error> -> L<IWL::Object> -> L<IWL::Widget> -> L<IWL::Input> -> L<IWL::Textarea>
 
 =head1 DESCRIPTION
 
@@ -117,7 +117,7 @@ sub getText {
 
 =item B<extractState> (B<STATE>)
 
-Update the IWL::Stash(3pm) B<STATE> according to the input state.
+Update the L<IWL::Stash> B<STATE> according to the input state.
 
 =cut
 
@@ -136,7 +136,7 @@ sub extractState {
 
 =item B<applyState> (B<STATE>)
 
-Update the input element according to the IWL::Stash(3pm) B<STATE>
+Update the input element according to the L<IWL::Stash> B<STATE>
 object.  The B<STATE> will get modified, i.e. the "used" element
 will be shifted from the according slot (name attribute) of the
 state.
