@@ -2,9 +2,8 @@
 var loaded = false;
 document.loaded = false;
 
-Event.signalConnect(window, "load", function () { loaded = true; });
+Event.signalConnect(window, "load", function () { window.loaded = true; });
 document.observe("dom:loaded", function() {
-    document.loaded = true;
     Event.signalConnect(document.body, "click", IWL.Focus.loseFocusCallback);
 });
 
@@ -13,19 +12,19 @@ Object.extend(IWL, {RPC: (function() {
   function eventStart(str) {
       return function(params) {
           eval(str);
-      }
+      };
   }
 
   function eventCompletion(str) {
       return function(json, params, options) {
           eval(str);
-      }
+      };
   }
 
   function eventFinalize (element, eventName, options) {
       if (options.disableView)
           IWL.View.enable();
-      element['handlers'][eventName].ajaxRequest = null
+      element['handlers'][eventName].ajaxRequest = null;
       if (options.emitOnce)
           delete element['handlers'][eventName];
   }
@@ -65,9 +64,9 @@ Object.extend(IWL, {RPC: (function() {
                       onComplete: function(or) {
                           var json = or.responseJSON;
                           if (!json) return;
-                          if (options.method && options.method in element) 
+                          if (Object.isFunction(element[options.method]))
                               element[options.method].call(element, json, params, options);
-                          if (options.responseCallback && typeof options.responseCallback === 'function') 
+                          if (Object.isFunction(options.responseCallback))
                               options.responseCallback.call(element, json, params, options);
                           if (options.onComplete) {
                               var callback = eventCompletion(options.onComplete);
@@ -82,7 +81,7 @@ Object.extend(IWL, {RPC: (function() {
                       onException: IWL.exceptionHandler,
                       onLoading: disable,
                       onComplete: function(or) {
-                          if (options.responseCallback && typeof options.responseCallback === 'function') 
+                          if (options.responseCallback && typeof options.responseCallback === 'function')
                               options.responseCallback.call(element, {}, params, options);
                           if (options.onComplete) {
                               var callback = eventCompletion(options.onComplete);
@@ -95,7 +94,7 @@ Object.extend(IWL, {RPC: (function() {
                       parameters: {IWLEvent: Object.toJSON({eventName: eventName, params: params, options: options})}
                   });
               }
-          }
+          };
           return element;
       },
       prepareEvents: function(element) {
@@ -137,11 +136,11 @@ IWL.Widget = {
 	if (this._preInit)
 	    if (!this._preInit.apply(this, arguments)) return;
 	Object.extend(this.current, this);
-  	if (this.current.prepareEvents)    
+  	if (this.current.prepareEvents)
             this.current.prepareEvents();
 	if (this.current._init)
 	    this.current._init.apply(this.current, arguments);
-     
+
         this.current.emitSignal('iwl:init');
         return this.current;
     },
@@ -149,7 +148,7 @@ IWL.Widget = {
 	if (!collection || !collection.each || !eventName) return;
 	collection.each(function(item) {
 	    if (item === exception) return;
-	    if (item['handlers'] 
+	    if (item['handlers']
 		&& item['handlers'][eventName]
 		&& item['handlers'][eventName].ajaxRequest)
 		item['handlers'][eventName].ajaxRequest.transport.abort();
@@ -160,7 +159,7 @@ IWL.Widget = {
 Object.extend(IWL, (function() {
     var script_urls = 0;
     var scripts     = [];
-    
+
     function evalScript () {
         if (--script_urls > 0) return;
         scripts.each(function(s) {
@@ -183,16 +182,8 @@ Object.extend(IWL, (function() {
             var flags = {disabled: true, multiple: true};
             if (!json || !(parentElement == $(parentElement))) return;
             previousElement = $(previousElement);
-            if (json.scripts) {
-                while (json.scripts.length) {
-                    var url = json.scripts.shift().attributes.src;
-                    ++script_urls;
-                    document.insertScript(url,
-                        {onComplete: evalScript, debug: IWL.Config.DEBUG, skipCache: IWL.Config.DEBUG});
-                }
-            }
             if (!json.tag) {
-                if (json.text === undefined || json.text === null) return false;
+                if ((json.text === undefined || json.text === null) && !json.environment) return false;
                 if (parentElement.tagName.toLowerCase() == 'script') {
                     if (script_urls)
                         scripts.push(json.text);
@@ -207,14 +198,24 @@ Object.extend(IWL, (function() {
                     var textNode = json.text.toString().createTextNode();
                     if (previousElement)
                         parentElement.insertBefore(textNode, previousElement);
-                    else 
+                    else
                         parentElement.appendChild(textNode);
                     return textNode;
                 }
+            } else if (json.tag == 'script' && json.attributes && json.attributes.src) {
+                var url = json.attributes.src;
+                ++script_urls;
+                return document.insertScript(url,
+                    {onComplete: evalScript, removeScriptElement: !IWL.Config.DEBUG, skipCache: IWL.Config.DEBUG});
             } else {
-                var attributes = Object.extend({}, json.attributes);
+                var attributes = {};
+		for (var attr in json.attributes) {
+		    var value = json.attributes[attr];
+		    if (Object.isString(value))
+			value = value.unescapeHTML();
+		    attributes[attr] = value;
+		}
                 if (attributes.style) {
-                    var time = new Date;
                     var style = $H(attributes.style);
                     attributes.style = style.keys().map(function(key) {
                         return [key, style.get(key)].join(": ");
@@ -261,7 +262,7 @@ Object.extend(IWL, (function() {
             var options = Object.extend({
                 fullCover: false,
                 noCover: false,
-                opacity: 0.8 
+                opacity: 0.8
             }, arguments[0] || {});
             disabled_view_cnt++;
 
@@ -324,7 +325,7 @@ Object.extend(IWL, (function() {
 Object.extend(IWL, (function() {
     var display_status_cnt = 0;
     var appear;
-    
+
     function hideStatus(options) {
         if (options.duration)
             IWL.Status.remove.delay(options.duration);
@@ -363,7 +364,7 @@ Object.extend(IWL, (function() {
             if (!status_bar) return;
             if (display_status_cnt >= 2) {
                 if (status_bar.firstChild)
-                    status_bar.removeChild(status_bar.firstChild); 
+                    status_bar.removeChild(status_bar.firstChild);
             }
             if (display_status_cnt-- <= 1) {
                 if (appear) {
@@ -443,15 +444,15 @@ IWL.keyLogger = function(element, callback) {
     var ElementMethods = {
         registerEvent: function(element, eventName, url, params, options) {
             IWL.RPC.registerEvent.apply(Event, arguments);
-            return $A(arguments).first();        
+            return $A(arguments).first();
         },
         prepareEvents: function(element) {
             IWL.RPC.prepareEvents.apply(Event, arguments);
-            return $A(arguments).first();       
+            return $A(arguments).first();
         },
         emitEvent: function(element, eventName, params, options) {
             IWL.RPC.emitEvent.apply(Event, arguments);
-            return $A(arguments).first();  
+            return $A(arguments).first();
         },
         hasEvent: function(element, eventName) {
             return IWL.RPC.hasEvent.apply(Event, arguments);
@@ -461,11 +462,11 @@ IWL.keyLogger = function(element, callback) {
         },
         registerFocus: function(element) {
             IWL.Focus.register.apply(IWL.Focus, arguments);
-            return element;  
+            return element;
         },
         keyLogger: function(element, callback) {
             IWL.keyLogger.apply(IWL, arguments);
-            return element;  
+            return element;
         }
     };
     Element.addMethods(ElementMethods);
@@ -489,6 +490,96 @@ Object.extend(document.viewport, {
     enable: IWL.View.enable
 });
 
+document.insertScript = (function () {
+  if (!document._urlCache)
+    document._urlCache = {};
+
+  if (Prototype.Browser.WebKit || Prototype.Browser.KHTML)
+    Prototype._helpers = [];
+
+  return function(url) {
+    if (!Object.isString(url) || url.blank());
+
+    var options = Object.extend({
+      onComplete: Prototype.emptyFunction,
+      skipCache: false,
+      removeScriptElement: true 
+    }, arguments[1]);
+
+    var scripts = $$('script').pluck('src');
+    scripts.each(function(src) {
+        var match = src.match(/IWLStaticURI=([^&]+)/);
+        if (match && match[1]) {
+            match[1].split(',').each(function(u) {
+                document._urlCache[u] = true;
+            });
+        };
+    });
+    var complete = false;
+    var match = url.match(/IWLStaticURI=([^&]+)/);
+    if (match && match[1]) {
+        var urls = match[1].split(',');
+        urls.clone().each(function(u) {
+            if (document._urlCache[u]) {
+                urls = urls.without(u);
+            } else {
+                document._urlCache[u] = true;
+            }
+        });
+        if (urls.length) {
+            url = url.replace(/IWLStaticURI=[^&]+/, 'IWLStaticURI=' + urls.join(','))
+        } else complete = true;
+    }
+
+    if (complete || document._urlCache[url] || scripts.invoke('endsWith', url).any()) {
+      document._urlCache[url] = true;
+      if (options.onComplete)
+        options.onComplete.bind(window, url).delay(0.1);
+      return;
+    }
+
+    document._urlCache[url] = true;
+    if (options.skipCache) {
+      var query = {_: (new Date).valueOf()};
+      var index = url.indexOf('?');
+      if (index != -1) {
+        Object.extend(query, url.substr(index).toQueryParams());
+        url = url.substr(0, index);
+      }
+      url += '?' + Object.toQueryString(query);
+    }
+
+    var script = new Element('script', {type: 'text/javascript', charset: 'utf-8'});
+    var fired = false;
+    var stateChangedCallback = function() {
+      if (fired) return;
+      if (script.readyState && script.readyState != 'loaded' &&
+          script.readyState != 'complete')
+        return;
+      script.onreadystatechange = script.onload = null;
+      if (options.onComplete) options.onComplete(url);
+      if (!options.removeScriptElement) script.remove();
+      fired = true;
+    };
+
+    script.onload = script.onreadystatechange = stateChangedCallback;
+    script.src = url;
+
+    document.getElementsByTagName('head').item(0).appendChild(script);
+
+    if ((Prototype.Browser.WebKit || Prototype.Browser.KHTML) && options.onComplete) {
+      var helper = new Element('script', {type: 'text/javascript'});
+      var index = Prototype._helpers.push({script: helper, callback: stateChangedCallback}) - 1;
+      helper.update(
+        'var helper = Prototype._helpers[' + index + '];helper.callback();' +
+        'helper.script.remove.delay(0.1);Prototype._helpers[' + index + '] = undefined'
+      );
+      Element.extend(document.body).appendChild.bind(document.body, helper).delay(0.1);
+    }
+  }
+})();
+
+
 /* Deprecated */
 var createHtmlElement = IWL.createHtmlElement;
 var disableView = IWL.View.disable;
