@@ -405,7 +405,9 @@ IWL.Calendar = Object.extend(Object.extend({}, IWL.Widget), (function() {
     function updateElement(element, format, date) {
         if (!(date instanceof Date))
             date = this.getDate();
-        if ("value" in element) {
+        if (Object.isFunction(element.setValue)) {
+            element.setValue(date.sprintf(format));
+        } else if ("value" in element) {
             element.value = date.sprintf(format);
             if (typeof element.onchange == 'function')
                 element.onchange.call(element);
@@ -738,7 +740,7 @@ IWL.Calendar = Object.extend(Object.extend({}, IWL.Widget), (function() {
             if (this.options.startDate instanceof Date)
                 this.startDate = this.date = this.options.startDate;
             else if (typeof this.options.startDate == 'number')
-                this.startDate = this.date = new Date(this.options.startDate)
+                this.startDate = this.date = new Date(this.options.startDate);
             else if (this.options.startDate.join) {
                 var date = this.options.startDate;
                 this.date = new Date();
@@ -784,7 +786,7 @@ IWL.Calendar = Object.extend(Object.extend({}, IWL.Widget), (function() {
             connectHeadingSignals.call(this);
             connectTimeSignals.call(this);
             this.keyLogger(keyEventsCB.bindAsEventListener(this));
-            this.registerFocus;
+            this.registerFocus();
 
             this.emitSignal('iwl:load');
         }
